# Glowing pancake

[![Build](https://github.com/mortenengen/glowing-pancake/actions/workflows/build.yaml/badge.svg)](https://github.com/mortenengen/glowing-pancake/actions/workflows/build.yaml)
[![Package version](https://badge.fury.io/py/glopan.svg)](https://badge.fury.io/py/glopan)
[![codecov](https://codecov.io/gh/mortenengen/glowing-pancake/branch/main/graph/badge.svg?token=9JJ6J5HQ02)](https://codecov.io/gh/mortenengen/glowing-pancake)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Checked with mypy](https://img.shields.io/badge/mypy-checked-blue)](http://mypy-lang.org/)

:::{toctree}
:hidden:
:caption: Contents

quickstart/index
configuration/index
api/index
CLI <cli/index>
:::

A simple Python package for converting figures and operating on pdfs.

See the [quickstart](quickstart) guide for an introduction to how to use `glopan`.
